# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`wireguard`](#wireguard): manages the wireguard package

### Defined types

* [`wireguard::interface`](#wireguardinterface): manages a wireguard setup

## Classes

### <a name="wireguard"></a>`wireguard`

manages the wireguard package

#### Parameters

The following parameters are available in the `wireguard` class:

* [`manage_package`](#manage_package)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`config_directory`](#config_directory)

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

if the package should be managed or not

Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `String[1]`

the name of the package

Default value: `'wireguard-tools'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['installed', 'latest', 'absent']`

the ensure state of the package

Default value: `'installed'`

##### <a name="config_directory"></a>`config_directory`

Data type: `Stdlib::Absolutepath`

the path to the wireguard directory

Default value: `'/etc/wireguard'`

## Defined types

### <a name="wireguardinterface"></a>`wireguard::interface`

manages a wireguard setup

#### Examples

##### 

```puppet
Peer with one node and setup dualstack firewall rules
wireguard::interface {'as2273':
  source_addresses => ['2003:4f8:c17:4cf::1', '149.9.255.4'],
  public_key       => 'BcxLll1BVxGQ5DeijroesjroiesjrjvX+EBhS4vcDn0R0=',
  endpoint         => 'wg.example.com:53668',
  addresses        => [{'Address' => '192.168.123.6/30',},{'Address' => 'fe80::beef:1/64'},],
}

Peer with one node and setup dualstack firewall rules with peers in a different layer2
wireguard::interface {'as2273':
  source_addresses => ['2003:4f8:c17:4cf::1', '149.9.255.4'],
  public_key       => 'BcxLll1BVxGQ5DeijroesjroiesjrjvX+EBhS4vcDn0R0=',
  endpoint         => 'wg.example.com:53668',
  addresses        => [{'Address' => '192.168.218.87/32', 'Peer' => '172.20.53.97/32'}, {'Address' => 'fe80::ade1/64',},],
}
```

#### Parameters

The following parameters are available in the `wireguard::interface` defined type:

* [`interface`](#interface)
* [`input_interface`](#input_interface)
* [`manage_firewall`](#manage_firewall)
* [`dport`](#dport)
* [`source_addresses`](#source_addresses)
* [`destination_addresses`](#destination_addresses)
* [`public_key`](#public_key)
* [`endpoint`](#endpoint)
* [`addresses`](#addresses)

##### <a name="interface"></a>`interface`

Data type: `String[1]`

the title of the defined resource, will be used for the wg interface

Default value: `$title`

##### <a name="input_interface"></a>`input_interface`

Data type: `Optional[String[1]]`

ethernet interface where the wireguard packages will enter the system, used for firewall rules

Default value: ``undef``

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

if true, a ferm rule will be created

Default value: ``true``

##### <a name="dport"></a>`dport`

Data type: `Integer[1024, 65000]`

destination for firewall rules / where our wg instance will listen on. defaults to the last digits from the title

Default value: `Integer(regsubst($title, '^\D+(\d+)$', '\1'))`

##### <a name="source_addresses"></a>`source_addresses`

Data type: `Optional[Array[Stdlib::IP::Address]]`

an array of ip addresses from where we receive wireguard connections

Default value: ``undef``

##### <a name="destination_addresses"></a>`destination_addresses`

Data type: `Optional[Array[Stdlib::IP::Address]]`

array of addresses where the remote peer connects to (our local ips), used for firewalling

Default value: `[$facts['networking']['ip'], $facts['networking']['ip6'],]`

##### <a name="public_key"></a>`public_key`

Data type: `String[1]`

base64 encoded pubkey from the remote peer

##### <a name="endpoint"></a>`endpoint`

Data type: `String[1]`

fqdn:port or ip:port where we connect to

##### <a name="addresses"></a>`addresses`

Data type: `Array[Hash[String,Variant[Stdlib::IP::Address::V4::CIDR,Stdlib::IP::Address::V6::CIDR]]]`

different addresses for the systemd-networkd configuration

Default value: `[]`

